<?xml version="1.0"  encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects.
======================================================================= -->
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

   <xsl:output
    	method="xml"
    	indent="yes"
    	encoding="UTF-8"/>

	<xsl:include href="xradar://stylesheets/radar/statics/process/master-merge.xsl"/>


	<xsl:param
    	name="input-report-file"/>

    <xsl:variable
    	name="cpd-report-doc"
    	select="document($input-report-file)"/>


	<xsl:variable
	    name="report-source"
	    select="'PMD-CPD'" />
	<xsl:variable
	    name="report-source-link"
	    select="'http://pmd.sourceforge.net/cpd.html'"/>

    <xsl:variable
        name="slash">
        <xsl:choose>
            <xsl:when test="contains($cpd-report-doc/pmd-cpd/duplication/file/@path,'/')"><xsl:value-of select="'/'"/></xsl:when>
            <xsl:otherwise><xsl:value-of select="'\'"/></xsl:otherwise>
        </xsl:choose>
    </xsl:variable>


   <xsl:template
    	match="Class">

       <xsl:variable
    		name="source-file-mod"
			select="concat(translate(normalize-space(node()),'.',$slash),'.java')"/>
       <xsl:variable
    		name="trash-file-string"
			select="substring-before($cpd-report-doc/pmd-cpd/duplication/file[contains(@path, $source-file-mod)]/@path,$source-file-mod)"/>

		<xsl:variable
			name="total-duplication-for-class"
			select="count($cpd-report-doc/pmd-cpd/duplication[count(file[contains(@path, $source-file-mod)]) &gt; 0])"/>


		<xsl:copy>
			<xsl:apply-templates select="@*|node()"/>
			<xsl:if test="$total-duplication-for-class &gt; 0">
				<duplications>
					<xsl:attribute name = "total-number" >
			        	<xsl:value-of select="$total-duplication-for-class"/>
			        </xsl:attribute>
					<xsl:apply-templates
						select="$cpd-report-doc/pmd-cpd/duplication[count(file[contains(@path, $source-file-mod)]) &gt; 0]">
						<xsl:with-param
						 	name="source-file-mod">
						 	<xsl:value-of select="$source-file-mod" />
						</xsl:with-param>
                        <xsl:with-param
						 	name="trash-file-string">
						 	<xsl:value-of select="$trash-file-string" />
						</xsl:with-param>
					</xsl:apply-templates>
				</duplications>
				<xsl:if test="not(node()/analysed-in-detail)">
					<analysed-in-detail/>
				</xsl:if>
			</xsl:if>
		</xsl:copy>
   </xsl:template>


   <xsl:template match="duplication">
		<xsl:param name="source-file-mod" />
		<xsl:param name="trash-file-string" />
        <xsl:copy>
        	<lines>
      			<xsl:value-of select="@lines"/>
      		</lines>
      		<tokens>
      			<xsl:value-of select="@tokens"/>
      		</tokens>
            <start-fragment>
      			<xsl:value-of select="substring(codefragment,1,100)"/>
      		</start-fragment>
            <xsl:for-each select="file">
                <classref>
                    <xsl:attribute name = "line" >
			        	<xsl:value-of select="@line"/>
			        </xsl:attribute>
                    <xsl:attribute name = "name" >
			        	<xsl:value-of select="translate(substring-before(substring-after(@path, $trash-file-string),'.java'),'\','.')"/>
			        </xsl:attribute>
                </classref>
            </xsl:for-each>
      	</xsl:copy>
   </xsl:template>

   <xsl:template name="package-addition"/>

</xsl:stylesheet>
